;use Function call
INCLUDE "hardware.inc"
SECTION "Header", ROM0[$100]

EntryPoint: ; This is where execution begins
    di ; Disable interrupts. That way we can avoid dealing with them, especially since we didn't talk about them yet :p
    jp Start ; Leave this tiny space
REPT $150 - $104
    db 0
ENDR

SECTION "Game code", ROM0

Start:
    ; Turn off the LCD
.waitVBlank
    ld a, [rLY]
    cp 144 ; Check if the LCD is past VBlank
    jr c, .waitVBlank

    xor a ; ld a, 0 ; We only need to reset a value with bit 7 reset, but 0 does the job
    ld [rLCDC], a ; We will have to write to LCDC again later, so it's not a bother, really.

;copy Tiles data
    ld de, Tiles
    ld hl, $9000
    ld bc, $40
    call Memcpy

;show Tiles
    ld hl, $9800
    ld [hl],$01
    ld hl, $9820
    ld [hl],$02
    ld hl, $9840
    ld [hl],$03

    ; Init display registers : color black 11 -> white 00
    ld a, %11100100
    ld [rBGP], a

    xor a ; ld a, 0
    ld [rSCY], a
    ld [rSCX], a

    ; Shut sound down
    ld [rNR52], a

    ; Turn screen on, display background
    ld a, %10000001
    ld [rLCDC], a

    ; Lock up
.lockup
    jr .lockup

section "Call Function", rom0
; Copy a string up to but not including the first NUL character
; @param de A pointer to the string to be copied
; @param hl A pointer to the beginning of the destination buffer
; @return de A pointer to the byte after the source string's terminating byte
; @return hl A pointer to the byte after the last copied byte
; @return a Zero
; @return flags C reset, Z set
Memcpy:
    ld a, [de]
    ld [hli], a
    inc de
    dec bc
    ld a, b
    or c
    jr nz, Memcpy
    ret

SECTION "Font", ROM0
Tiles:
;Plane1
;11111111   $FF
;10000001   $81
;10000001
;10000001
;10000001
;10000001
;10000001
;11111111

;Plane2
;11111111
;10000001
;10000001
;10000001
;10000001
;10000001
;10000001
;11111111
;จะเรียงข้อมูลสลับที่ละ row โดย row ข้อมูลเท่ากับ 1 byte
;สี 11 black, 10 dark grey, 01 light grey, 00 white
    db $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 ; Tile Number 0 
    db $FF,$00,$81,$00,$81,$00,$81,$00,$81,$00,$81,$00,$81,$00,$FF,$00 ; Tile Number 1    
    db $00,$FF,$00,$81,$00,$81,$00,$81,$00,$81,$00,$81,$00,$81,$00,$FF ; Tile Number 2 
    db $FF,$FF,$81,$81,$81,$81,$81,$81,$81,$81,$81,$81,$81,$81,$FF,$FF ; Tile Number 3 color Black
